==> jc-1.4.0.tar.gz: polyglot/lex/EscapedUnicodeReader.h <==
// public class polyglot.lex.EscapedUnicodeReader

// class file dependencies
// @dep_class cd1b0cd67de1a4a8 java_io_FilterReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 155ae8bbb3cb39cb polyglot_lex_EscapedUnicodeReader

// header file dependencies
// @dep_header java_io_FilterReader

#include "java/io/FilterReader.h"

#ifndef _JC_polyglot_lex_EscapedUnicodeReader_H_
#define _JC_polyglot_lex_EscapedUnicodeReader_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$sub_refs	_jc_polyglot_lex_EscapedUnicodeReader$sub_refs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs	_jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$refs	_jc_polyglot_lex_EscapedUnicodeReader$refs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$nonrefs	_jc_polyglot_lex_EscapedUnicodeReader$nonrefs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$object	_jc_polyglot_lex_EscapedUnicodeReader$object;

typedef const struct _jc_polyglot_lex_EscapedUnicodeReader$vmethods	_jc_polyglot_lex_EscapedUnicodeReader$vmethods;
typedef const struct _jc_polyglot_lex_EscapedUnicodeReader$vtable	_jc_polyglot_lex_EscapedUnicodeReader$vtable;
typedef const struct _jc_polyglot_lex_EscapedUnicodeReader$vtype	_jc_polyglot_lex_EscapedUnicodeReader$vtype;

// Constructors
extern void _jc_polyglot_lex_EscapedUnicodeReader$method$_init$cc321c4706192fe8(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *, struct _jc_java_io_Reader$object *);

// Virtual methods
extern jboolean _jc_polyglot_lex_EscapedUnicodeReader$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *);
extern jint _jc_polyglot_lex_EscapedUnicodeReader$method$read$1a981297cb524963(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *);
extern jint _jc_polyglot_lex_EscapedUnicodeReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *, struct _jc_char_array *, jint, jint);
extern jboolean _jc_polyglot_lex_EscapedUnicodeReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$ready$83ea616797d9c364;

// Virtual methods structure
struct _jc_polyglot_lex_EscapedUnicodeReader$vmethods {
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *);
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *, struct _jc_char_array *, jint, jint);
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *);
};

// Vtable
struct _jc_polyglot_lex_EscapedUnicodeReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_FilterReader$vmethods	java_io_FilterReader;
	_jc_polyglot_lex_EscapedUnicodeReader$vmethods	polyglot_lex_EscapedUnicodeReader;
};

// Vtype
struct _jc_polyglot_lex_EscapedUnicodeReader$vtype {
	_jc_type			type;
	_jc_polyglot_lex_EscapedUnicodeReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_EscapedUnicodeReader$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_EscapedUnicodeReader$refs {
    _jc_polyglot_lex_EscapedUnicodeReader$sub_refs	polyglot_lex_EscapedUnicodeReader;
    _jc_java_io_FilterReader$sub_refs	java_io_FilterReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs {
	jint	pushback;
	jboolean	isEvenSlash;
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_EscapedUnicodeReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_FilterReader$sub_nonrefs	java_io_FilterReader;
    _jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs	polyglot_lex_EscapedUnicodeReader;
};

// Object instance structure
struct _jc_polyglot_lex_EscapedUnicodeReader$object {
	_jc_polyglot_lex_EscapedUnicodeReader$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_EscapedUnicodeReader$vtype	*vtype;
	_jc_polyglot_lex_EscapedUnicodeReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_EscapedUnicodeReader$vtype _jc_polyglot_lex_EscapedUnicodeReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_EscapedUnicodeReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_EscapedUnicodeReader$class_object;

#endif	/* _JC_polyglot_lex_EscapedUnicodeReader_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/EscapedUnicodeReader.h <==
// public class polyglot.lex.EscapedUnicodeReader

// class file dependencies
// @dep_class cd1b0cd67de1a4a8 java_io_FilterReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 155ae8bbb3cb39cb polyglot_lex_EscapedUnicodeReader

// header file dependencies
// @dep_header java_io_FilterReader

#include "java/io/FilterReader.h"

#ifndef _JC_polyglot_lex_EscapedUnicodeReader_H_
#define _JC_polyglot_lex_EscapedUnicodeReader_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$sub_refs	_jc_polyglot_lex_EscapedUnicodeReader$sub_refs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs	_jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$refs	_jc_polyglot_lex_EscapedUnicodeReader$refs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$nonrefs	_jc_polyglot_lex_EscapedUnicodeReader$nonrefs;
typedef struct _jc_polyglot_lex_EscapedUnicodeReader$object	_jc_polyglot_lex_EscapedUnicodeReader$object;

typedef const struct _jc_polyglot_lex_EscapedUnicodeReader$vmethods	_jc_polyglot_lex_EscapedUnicodeReader$vmethods;
typedef const struct _jc_polyglot_lex_EscapedUnicodeReader$vtable	_jc_polyglot_lex_EscapedUnicodeReader$vtable;
typedef const struct _jc_polyglot_lex_EscapedUnicodeReader$vtype	_jc_polyglot_lex_EscapedUnicodeReader$vtype;

// Constructors
extern void _jc_polyglot_lex_EscapedUnicodeReader$method$_init$cc321c4706192fe8(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *, struct _jc_java_io_Reader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_lex_EscapedUnicodeReader$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_lex_EscapedUnicodeReader$method$read$1a981297cb524963(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_lex_EscapedUnicodeReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_lex_EscapedUnicodeReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_polyglot_lex_EscapedUnicodeReader$method_info$ready$83ea616797d9c364;

// Virtual methods structure
struct _jc_polyglot_lex_EscapedUnicodeReader$vmethods {
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *) _JC_JCNI_ATTR;
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_polyglot_lex_EscapedUnicodeReader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_EscapedUnicodeReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_FilterReader$vmethods	java_io_FilterReader;
	_jc_polyglot_lex_EscapedUnicodeReader$vmethods	polyglot_lex_EscapedUnicodeReader;
};

// Vtype
struct _jc_polyglot_lex_EscapedUnicodeReader$vtype {
	_jc_type			type;
	_jc_polyglot_lex_EscapedUnicodeReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_EscapedUnicodeReader$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_EscapedUnicodeReader$refs {
    _jc_polyglot_lex_EscapedUnicodeReader$sub_refs	polyglot_lex_EscapedUnicodeReader;
    _jc_java_io_FilterReader$sub_refs	java_io_FilterReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs {
	jint	pushback;
	jboolean	isEvenSlash;
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_EscapedUnicodeReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_FilterReader$sub_nonrefs	java_io_FilterReader;
    _jc_polyglot_lex_EscapedUnicodeReader$sub_nonrefs	polyglot_lex_EscapedUnicodeReader;
};

// Object instance structure
struct _jc_polyglot_lex_EscapedUnicodeReader$object {
	_jc_polyglot_lex_EscapedUnicodeReader$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_EscapedUnicodeReader$vtype	*vtype;
	_jc_polyglot_lex_EscapedUnicodeReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_EscapedUnicodeReader$vtype _jc_polyglot_lex_EscapedUnicodeReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_EscapedUnicodeReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_EscapedUnicodeReader$class_object;

#endif	/* _JC_polyglot_lex_EscapedUnicodeReader_H_ */
